==> angular-prism-0.1.0.tgz: package/index.js <==
import { Component, ElementRef, Input, NgModule, ViewChild } from '@angular/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var PrismComponent = (function () {
    function PrismComponent(elementRef) {
        this.elementRef = elementRef;
    }
    /**
     * @return {?}
     */
    PrismComponent.prototype.onContentChanged = /**
     * @return {?}
     */
    function () {
        this.codeViewChild.nativeElement.innerHTML = this.code ? this.code : this.rawViewChild.nativeElement.innerHTML;
        Prism.highlightElement(this.codeViewChild.nativeElement);
    };
    /**
     * @return {?}
     */
    PrismComponent.prototype.ngAfterViewInit = /**
     * @return {?}
     */
    function () {
        this.onContentChanged();
    };
    /**
     * @return {?}
     */
    PrismComponent.prototype.ngAfterContentInit = /**
     * @return {?}
     */
    function () {
        this.observer = new MutationObserver(this.onContentChanged.bind(this));
        this.observer.observe(this.rawViewChild.nativeElement, {
            'characterData': true,
            'childList': true,
            'subtree': true
        });
    };
    /**
     * @return {?}
     */
    PrismComponent.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        if (this.observer) {
            this.observer.disconnect();
        }
    };
    PrismComponent.decorators = [
        { type: Component, args: [{
                    selector: 'prism',
                    template: "\n    <div hidden #raw style=\"display: none\"><ng-content></ng-content></div>\n    <pre class=\"language-{{language}}\"><code #code></code></pre>\n  "
                },] },
    ];
    /** @nocollapse */
    PrismComponent.ctorParameters = function () { return [
        { type: ElementRef, },
    ]; };
    PrismComponent.propDecorators = {
        "language": [{ type: Input },],
        "code": [{ type: Input },],
        "rawViewChild": [{ type: ViewChild, args: ['raw',] },],
        "codeViewChild": [{ type: ViewChild, args: ['code',] },],
    };
    return PrismComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var PrismModule = (function () {
    function PrismModule() {
    }
    PrismModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule
                    ],
                    declarations: [
                        PrismComponent
                    ],
                    exports: [
                        PrismComponent
                    ]
                },] },
    ];
    /** @nocollapse */
    PrismModule.ctorParameters = function () { return []; };
    return PrismModule;
}());

export { PrismModule, PrismComponent };

==> angular-prism-0.2.0.tgz: package/index.js <==
import { Component, ElementRef, Input, NgModule, ViewChild } from '@angular/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var PrismComponent = (function () {
    function PrismComponent(elementRef) {
        this.elementRef = elementRef;
    }
    /**
     * @return {?}
     */
    PrismComponent.prototype.onContentChanged = /**
     * @return {?}
     */
    function () {
        this.codeViewChild.nativeElement.innerHTML = this.code ?
            this.encodeEntities(this.code) : this.rawViewChild.nativeElement.innerHTML;
        Prism.highlightElement(this.codeViewChild.nativeElement);
    };
    /**
     * @return {?}
     */
    PrismComponent.prototype.ngAfterViewInit = /**
     * @return {?}
     */
    function () {
        this.onContentChanged();
    };
    /**
     * @return {?}
     */
    PrismComponent.prototype.ngOnChanges = /**
     * @return {?}
     */
    function () {
        this.onContentChanged();
    };
    /**
     * @return {?}
     */
    PrismComponent.prototype.ngAfterContentInit = /**
     * @return {?}
     */
    function () {
        this.observer = new MutationObserver(this.onContentChanged.bind(this));
        this.observer.observe(this.rawViewChild.nativeElement, {
            'characterData': true,
            'childList': true,
            'subtree': true
        });
    };
    /**
     * @return {?}
     */
    PrismComponent.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        if (this.observer) {
            this.observer.disconnect();
        }
    };
    /**
     * @param {?} value
     * @return {?}
     */
    PrismComponent.prototype.encodeEntities = /**
     * @param {?} value
     * @return {?}
     */
    function (value) {
        return value
            .replace(/&/g, '&amp;')
            .replace(/"/g, '&quot;')
            .replace(/'/g, '&#39;')
            .replace(/</g, '&lt;')
            .replace(/>/g, '&gt;');
    };
    PrismComponent.decorators = [
        { type: Component, args: [{
                    selector: 'prism',
                    template: "\n    <div hidden #raw style=\"display: none\"><ng-content></ng-content></div>\n    <pre class=\"language-{{language}}\"><code #code></code></pre>\n  "
                },] },
    ];
    /** @nocollapse */
    PrismComponent.ctorParameters = function () { return [
        { type: ElementRef, },
    ]; };
    PrismComponent.propDecorators = {
        "language": [{ type: Input },],
        "code": [{ type: Input },],
        "rawViewChild": [{ type: ViewChild, args: ['raw',] },],
        "codeViewChild": [{ type: ViewChild, args: ['code',] },],
    };
    return PrismComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var PrismModule = (function () {
    function PrismModule() {
    }
    PrismModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule
                    ],
                    declarations: [
                        PrismComponent
                    ],
                    exports: [
                        PrismComponent
                    ]
                },] },
    ];
    /** @nocollapse */
    PrismModule.ctorParameters = function () { return []; };
    return PrismModule;
}());

export { PrismModule, PrismComponent };
